==> ejc-scientific-impl-3.0.0-20250307.091015-45-sources.jar: com/ejianc/business/scientific/sci/service/impl/FeeConfirmServiceImpl.java <==
package com.ejianc.business.scientific.sci.service.impl;

import com.ejianc.business.scientific.sci.bean.ExecuteEntity;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.stereotype.Service;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;

import com.ejianc.business.scientific.sci.mapper.FeeConfirmMapper;
import com.ejianc.business.scientific.sci.bean.FeeConfirmEntity;
import com.ejianc.business.scientific.sci.service.IFeeConfirmService;

import java.util.List;
import java.util.stream.Collectors;

/**
 * 科研经费确认
 * 
 * @author generator
 * 
 */
@Service("feeConfirmService")
public class FeeConfirmServiceImpl extends BaseServiceImpl<FeeConfirmMapper, FeeConfirmEntity> implements IFeeConfirmService{

    @Override
    public String validateProjectId(Long projectId, Long id, String operation) {
        //同一个项目只能存在一个自由态或审批中的单据
        QueryParam queryParam = new QueryParam();
        queryParam.getParams().put("projectId", new Parameter(QueryParam.EQ, projectId));
        if(id != null){
            queryParam.getParams().put("id", new Parameter(QueryParam.NE, id));
        }
        List<FeeConfirmEntity> list = super.queryList(queryParam, false);
        List<FeeConfirmEntity> freeList = list.stream().filter(x->1 !=x.getBillState() && 3 !=x.getBillState()).collect(Collectors.toList());
        if (CollectionUtils.isNotEmpty(freeList)) {
            throw new BusinessException("该科研项目存在非生效态的经费确认单，不能" + operation + "!");
        }
        return "校验成功！";
    }
}

==> ejc-scientific-impl-3.0.0-20250901.130831-93-sources.jar: com/ejianc/business/scientific/sci/service/impl/FeeConfirmServiceImpl.java <==
package com.ejianc.business.scientific.sci.service.impl;

import com.ejianc.business.scientific.sci.bean.FeeConfirmEntity;
import com.ejianc.business.scientific.sci.mapper.FeeConfirmMapper;
import com.ejianc.business.scientific.sci.service.IFeeConfirmService;
import com.ejianc.business.scientific.sci.vo.FeeConfirmVO;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import com.ejianc.framework.core.util.ComputeUtil;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.apache.commons.collections.CollectionUtils;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 科研经费确认
 * 
 * @author generator
 * 
 */
@Service("feeConfirmService")
public class FeeConfirmServiceImpl extends BaseServiceImpl<FeeConfirmMapper, FeeConfirmEntity> implements IFeeConfirmService{

    @Override
    public FeeConfirmVO validateProjectId(Long projectId, Long id, String operation) {
        //同一个项目只能存在一个自由态或审批中的单据
        QueryParam queryParam = new QueryParam();
        queryParam.getParams().put("projectId", new Parameter(QueryParam.EQ, projectId));
        if(id != null){
            queryParam.getParams().put("id", new Parameter(QueryParam.NE, id));
        }
        List<FeeConfirmEntity> list = super.queryList(queryParam, false);
        List<FeeConfirmEntity> freeList = list.stream().filter(x->1 !=x.getBillState() && 3 !=x.getBillState()).collect(Collectors.toList());
        if (CollectionUtils.isNotEmpty(freeList)) {
            throw new BusinessException("该科研项目存在非生效态的经费确认单，不能" + operation + "!");
        }
        FeeConfirmVO vo = new FeeConfirmVO();
        BigDecimal lastApplyMny = list.stream().filter(x->1 == x.getBillState() || 3 ==x.getBillState()).map(x->x.getApplyMny()).reduce(BigDecimal.ZERO, ComputeUtil::safeAdd);
        vo.setLastApplyMny(lastApplyMny);
        return vo;
    }
}
